var Child = /*#__PURE__*/function (_Base) {
  "use strict";

  babelHelpers.inherits(Child, _Base);

  var _super = babelHelpers.createSuper(Child);

  function Child() {
    var _this;

    babelHelpers.classCallCheck(this, Child);
    return babelHelpers.possibleConstructorReturn(_this, {});
  }

  return Child;
}(Base);
